==> key-server-api-0.0.1-20150729.054357-11-sources.jar: com/xdja/cssp/key/server/api/bean/KsfBean.java <==
package com.xdja.cssp.key.server.api.bean;

import java.io.Serializable;

/**
 * 
 * 
 * Project Name：key-server-api
 * ClassName：KsgBean
 * Description：ksgBean
 * @author: 谢文超
 * @date: 2015-7-10 上午11:28:19
 * note:
 *
 */
public class KsfBean implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 当前帐号
	 */
	private String account;
	
	private String ksfId;
	
	/**
	 * 与friendAccount间的会话密钥
	 */
	private String encryptKsf;
	
	private Long kuepId;
	
	/**
	 * 好友账号
	 */
	private String friendAccount;
	
	private Long friendkuepId;
	/**
	 * 好友账号会话密钥
	 */
	private String encryptFriendKsf;

	/**
	 * @return 获取account
	 */
	public String getAccount() {
		return account;
	}

	/**
	 * @param 设置account
	 */
	public void setAccount(String account) {
		this.account = account;
	}

	/**
	 * @return 获取encryptKsf
	 */
	public String getEncryptKsf() {
		return encryptKsf;
	}

	/**
	 * @param 设置encryptKsf
	 */
	public void setEncryptKsf(String encryptKsf) {
		this.encryptKsf = encryptKsf;
	}

	/**
	 * @return 获取kuepId
	 */
	public Long getKuepId() {
		return kuepId;
	}

	/**
	 * @param 设置kuepId
	 */
	public void setKuepId(Long kuepId) {
		this.kuepId = kuepId;
	}

	/**
	 * @return 获取friendAccount
	 */
	public String getFriendAccount() {
		return friendAccount;
	}

	/**
	 * @param 设置friendAccount
	 */
	public void setFriendAccount(String friendAccount) {
		this.friendAccount = friendAccount;
	}

	/**
	 * @return 获取friendkuepId
	 */
	public Long getFriendkuepId() {
		return friendkuepId;
	}

	/**
	 * @param 设置friendkuepId
	 */
	public void setFriendkuepId(Long friendkuepId) {
		this.friendkuepId = friendkuepId;
	}

	/**
	 * @return 获取encryptFriendKsf
	 */
	public String getEncryptFriendKsf() {
		return encryptFriendKsf;
	}

	/**
	 * @param 设置encryptFriendKsf
	 */
	public void setEncryptFriendKsf(String encryptFriendKsf) {
		this.encryptFriendKsf = encryptFriendKsf;
	}

	/**
	 * @return 获取ksfId
	 */
	public String getKsfId() {
		return ksfId;
	}

	/**
	 * @param 设置ksfId
	 */
	public void setKsfId(String ksfId) {
		this.ksfId = ksfId;
	}
	
}

==> key-server-api-0.0.1-20151010.022016-17-sources.jar: com/xdja/cssp/key/server/api/bean/KsfBean.java <==
package com.xdja.cssp.key.server.api.bean;

import java.io.Serializable;

/**
 * 
 * 
 * Project Name：key-server-api
 * ClassName：KsgBean
 * Description：ksgBean
 * @author: 谢文超
 * @date: 2015-7-10 上午11:28:19
 * note:
 *
 */
public class KsfBean implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 当前帐号
	 */
	private String account;
	
	private String ksfId;
	
	/**
	 * 与friendAccount间的会话密钥
	 */
	private String encryptKsf;
	
	private Long kuepId;
	
	/**
	 * 好友账号
	 */
	private String friendAccount;
	
	private Long friendkuepId;
	/**
	 * 好友账号会话密钥
	 */
	private String encryptFriendKsf;

	/**
	 * @return 获取account
	 */
	public String getAccount() {
		return account;
	}

	/**
	 * @param 设置account
	 */
	public void setAccount(String account) {
		this.account = account;
	}

	/**
	 * @return 获取encryptKsf
	 */
	public String getEncryptKsf() {
		return encryptKsf;
	}

	/**
	 * @param 设置encryptKsf
	 */
	public void setEncryptKsf(String encryptKsf) {
		this.encryptKsf = encryptKsf;
	}

	/**
	 * @return 获取kuepId
	 */
	public Long getKuepId() {
		return kuepId;
	}

	/**
	 * @param 设置kuepId
	 */
	public void setKuepId(Long kuepId) {
		this.kuepId = kuepId;
	}

	/**
	 * @return 获取friendAccount
	 */
	public String getFriendAccount() {
		return friendAccount;
	}

	/**
	 * @param 设置friendAccount
	 */
	public void setFriendAccount(String friendAccount) {
		this.friendAccount = friendAccount;
	}

	/**
	 * @return 获取friendkuepId
	 */
	public Long getFriendkuepId() {
		return friendkuepId;
	}

	/**
	 * @param 设置friendkuepId
	 */
	public void setFriendkuepId(Long friendkuepId) {
		this.friendkuepId = friendkuepId;
	}

	/**
	 * @return 获取encryptFriendKsf
	 */
	public String getEncryptFriendKsf() {
		return encryptFriendKsf;
	}

	/**
	 * @param 设置encryptFriendKsf
	 */
	public void setEncryptFriendKsf(String encryptFriendKsf) {
		this.encryptFriendKsf = encryptFriendKsf;
	}

	/**
	 * @return 获取ksfId
	 */
	public String getKsfId() {
		return ksfId;
	}

	/**
	 * @param 设置ksfId
	 */
	public void setKsfId(String ksfId) {
		this.ksfId = ksfId;
	}
	
	@Override
	public String toString() {
		return "KsfBean [kuepId:" + kuepId + ", ksfId:" + ksfId 
				+ ", account:" + account + ", encryptKsf:" + encryptKsf  
				+ ", friendkuepId:" + friendkuepId + ", friendAccount:" 
				+ friendAccount + ", encryptFriendKsf:" + encryptFriendKsf + "]";
	}
	
}
